// Copyright (c) 2015, <your name>. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.


library orientdb_server.base;

import 'dart:async';
import 'dart:io';
import 'dart:convert';
/// Checks if you are awesome. Spoiler: you are.
class Awesome {
  bool get isAwesome => true;
}

class OrientDB_UrlParts {
  String userName;
  String password;
  String host;
  int port;

  static final Storage MEMORY = new Storage('memory');
  static final Storage LOCAL = new Storage('plocal');
  static final DBType DOC = new DBType('document');
  static final DBType GRAPH = new DBType('graph');




  OrientDB_UrlParts(this.userName, this.password, this.host, this.port);

  String shortToString() => "$host:$port";
  String longToString() => "$userName:$password@$host:$port";

  Future<List> databaseList() {
    List list = new List();
    var completer = new Completer();
    HttpClient client = new HttpClient();
    client.getUrl(Uri.parse("http://${this.shortToString()}/listDatabases")).then((clientRequest) {
      return clientRequest.close();
    }).then((clientResponse) {
      clientResponse.transform(UTF8.decoder).listen((contents) {
        var json = JSON.decode(contents);
        for (String database in json['databases']) {
          list.add(database);
        }
        completer.complete(list);

      });
    });
    return completer.future;
  }

  // default values - storage is on disc; the database stores documents
  Future<bool> createDatabase(String database, {Storage storage, DBType dbType}) {
    var completer = new Completer();
    if (storage == null) {
      storage = LOCAL;
    }
    if (dbType == null) {
      dbType = DOC;
    }
    HttpClient client = new HttpClient();
    client.postUrl(Uri.parse("http://${this.longToString()}/database/$database/${storage.value}/${dbType.value}"))
        .then((clientRequest){
      return clientRequest.close();
    }).then((clientResponse) {
      clientResponse.transform(UTF8.decoder).listen((contents) {
        print("$contents, ${clientResponse.statusCode}");
        bool result = (clientResponse.statusCode == 200);
        completer.complete(result);
      });
    });
    return completer.future;
  }

  deleteDatabase(String database) {
    HttpClient client = new HttpClient();
    client.deleteUrl(Uri.parse("http://${this.longToString()}/database/$database"))
    .then((clientRequest) {
      return clientRequest.close();
    });
  }
}




class Storage {
  String value;
  Storage(this.value);
}

class DBType {
  String value;
  DBType(this.value);
}




